==> openshift-model-operator-5.4.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/EndpointPublishingStrategyFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

public interface EndpointPublishingStrategyFluent<A extends io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildHostNetwork instead.
     * @return The buildable object.
     */
        public io.fabric8.openshift.api.model.operator.v1.HostNetworkStrategy getHostNetwork();
    public io.fabric8.openshift.api.model.operator.v1.HostNetworkStrategy buildHostNetwork();
    public A withHostNetwork(io.fabric8.openshift.api.model.operator.v1.HostNetworkStrategy hostNetwork);
    public java.lang.Boolean hasHostNetwork();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.HostNetworkNested<A> withNewHostNetwork();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.HostNetworkNested<A> withNewHostNetworkLike(io.fabric8.openshift.api.model.operator.v1.HostNetworkStrategy item);
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.HostNetworkNested<A> editHostNetwork();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.HostNetworkNested<A> editOrNewHostNetwork();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.HostNetworkNested<A> editOrNewHostNetworkLike(io.fabric8.openshift.api.model.operator.v1.HostNetworkStrategy item);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildLoadBalancer instead.
     * @return The buildable object.
     */
        public io.fabric8.openshift.api.model.operator.v1.LoadBalancerStrategy getLoadBalancer();
    public io.fabric8.openshift.api.model.operator.v1.LoadBalancerStrategy buildLoadBalancer();
    public A withLoadBalancer(io.fabric8.openshift.api.model.operator.v1.LoadBalancerStrategy loadBalancer);
    public java.lang.Boolean hasLoadBalancer();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.LoadBalancerNested<A> withNewLoadBalancer();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.LoadBalancerNested<A> withNewLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.LoadBalancerStrategy item);
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.LoadBalancerNested<A> editLoadBalancer();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.LoadBalancerNested<A> editOrNewLoadBalancer();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.LoadBalancerNested<A> editOrNewLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.LoadBalancerStrategy item);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildNodePort instead.
     * @return The buildable object.
     */
        public io.fabric8.openshift.api.model.operator.v1.NodePortStrategy getNodePort();
    public io.fabric8.openshift.api.model.operator.v1.NodePortStrategy buildNodePort();
    public A withNodePort(io.fabric8.openshift.api.model.operator.v1.NodePortStrategy nodePort);
    public java.lang.Boolean hasNodePort();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.NodePortNested<A> withNewNodePort();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.NodePortNested<A> withNewNodePortLike(io.fabric8.openshift.api.model.operator.v1.NodePortStrategy item);
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.NodePortNested<A> editNodePort();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.NodePortNested<A> editOrNewNodePort();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.NodePortNested<A> editOrNewNodePortLike(io.fabric8.openshift.api.model.operator.v1.NodePortStrategy item);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildPrivate instead.
     * @return The buildable object.
     */
        public io.fabric8.openshift.api.model.operator.v1.PrivateStrategy getPrivate();
    public io.fabric8.openshift.api.model.operator.v1.PrivateStrategy buildPrivate();
    public A withPrivate(io.fabric8.openshift.api.model.operator.v1.PrivateStrategy _private);
    public java.lang.Boolean hasPrivate();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.PrivateNested<A> withNewPrivate();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.PrivateNested<A> withNewPrivateLike(io.fabric8.openshift.api.model.operator.v1.PrivateStrategy item);
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.PrivateNested<A> editPrivate();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.PrivateNested<A> editOrNewPrivate();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.PrivateNested<A> editOrNewPrivateLike(io.fabric8.openshift.api.model.operator.v1.PrivateStrategy item);
    public java.lang.String getType();
    public A withType(java.lang.String type);
    public java.lang.Boolean hasType();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withType instead.
     */
        public A withNewType(java.lang.String arg0);
    public interface HostNetworkNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.HostNetworkStrategyFluent<io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.HostNetworkNested<N>> {

            public N and();
            public N endHostNetwork();    }


    public interface LoadBalancerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.LoadBalancerStrategyFluent<io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.LoadBalancerNested<N>> {

            public N and();
            public N endLoadBalancer();    }


    public interface NodePortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.NodePortStrategyFluent<io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.NodePortNested<N>> {

            public N and();
            public N endNodePort();    }


    public interface PrivateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.PrivateStrategyFluent<io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.PrivateNested<N>> {

            public N and();
            public N endPrivate();    }


}

==> openshift-model-operator-5.7.0-sources.jar: io/fabric8/openshift/api/model/operator/v1/EndpointPublishingStrategyFluent.java <==
package io.fabric8.openshift.api.model.operator.v1;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.builder.Fluent;
import java.lang.Object;
import java.util.Map;

public interface EndpointPublishingStrategyFluent<A extends io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A> {


    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildHostNetwork instead.
     * @return The buildable object.
     */
        public io.fabric8.openshift.api.model.operator.v1.HostNetworkStrategy getHostNetwork();
    public io.fabric8.openshift.api.model.operator.v1.HostNetworkStrategy buildHostNetwork();
    public A withHostNetwork(io.fabric8.openshift.api.model.operator.v1.HostNetworkStrategy hostNetwork);
    public java.lang.Boolean hasHostNetwork();
    public A withNewHostNetwork(java.lang.String protocol);
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.HostNetworkNested<A> withNewHostNetwork();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.HostNetworkNested<A> withNewHostNetworkLike(io.fabric8.openshift.api.model.operator.v1.HostNetworkStrategy item);
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.HostNetworkNested<A> editHostNetwork();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.HostNetworkNested<A> editOrNewHostNetwork();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.HostNetworkNested<A> editOrNewHostNetworkLike(io.fabric8.openshift.api.model.operator.v1.HostNetworkStrategy item);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildLoadBalancer instead.
     * @return The buildable object.
     */
        public io.fabric8.openshift.api.model.operator.v1.LoadBalancerStrategy getLoadBalancer();
    public io.fabric8.openshift.api.model.operator.v1.LoadBalancerStrategy buildLoadBalancer();
    public A withLoadBalancer(io.fabric8.openshift.api.model.operator.v1.LoadBalancerStrategy loadBalancer);
    public java.lang.Boolean hasLoadBalancer();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.LoadBalancerNested<A> withNewLoadBalancer();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.LoadBalancerNested<A> withNewLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.LoadBalancerStrategy item);
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.LoadBalancerNested<A> editLoadBalancer();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.LoadBalancerNested<A> editOrNewLoadBalancer();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.LoadBalancerNested<A> editOrNewLoadBalancerLike(io.fabric8.openshift.api.model.operator.v1.LoadBalancerStrategy item);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildNodePort instead.
     * @return The buildable object.
     */
        public io.fabric8.openshift.api.model.operator.v1.NodePortStrategy getNodePort();
    public io.fabric8.openshift.api.model.operator.v1.NodePortStrategy buildNodePort();
    public A withNodePort(io.fabric8.openshift.api.model.operator.v1.NodePortStrategy nodePort);
    public java.lang.Boolean hasNodePort();
    public A withNewNodePort(java.lang.String protocol);
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.NodePortNested<A> withNewNodePort();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.NodePortNested<A> withNewNodePortLike(io.fabric8.openshift.api.model.operator.v1.NodePortStrategy item);
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.NodePortNested<A> editNodePort();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.NodePortNested<A> editOrNewNodePort();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.NodePortNested<A> editOrNewNodePortLike(io.fabric8.openshift.api.model.operator.v1.NodePortStrategy item);
    
    @java.lang.Deprecated
        
    /**
     * This method has been deprecated, please use method buildPrivate instead.
     * @return The buildable object.
     */
        public io.fabric8.openshift.api.model.operator.v1.PrivateStrategy getPrivate();
    public io.fabric8.openshift.api.model.operator.v1.PrivateStrategy buildPrivate();
    public A withPrivate(io.fabric8.openshift.api.model.operator.v1.PrivateStrategy _private);
    public java.lang.Boolean hasPrivate();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.PrivateNested<A> withNewPrivate();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.PrivateNested<A> withNewPrivateLike(io.fabric8.openshift.api.model.operator.v1.PrivateStrategy item);
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.PrivateNested<A> editPrivate();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.PrivateNested<A> editOrNewPrivate();
    public io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.PrivateNested<A> editOrNewPrivateLike(io.fabric8.openshift.api.model.operator.v1.PrivateStrategy item);
    public java.lang.String getType();
    public A withType(java.lang.String type);
    public java.lang.Boolean hasType();
    
    @java.lang.Deprecated
        
    /**
     * Method is deprecated. use withType instead.
     */
        public A withNewType(java.lang.String arg0);
    public interface HostNetworkNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.HostNetworkStrategyFluent<io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.HostNetworkNested<N>> {

            public N and();
            public N endHostNetwork();    }


    public interface LoadBalancerNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.LoadBalancerStrategyFluent<io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.LoadBalancerNested<N>> {

            public N and();
            public N endLoadBalancer();    }


    public interface NodePortNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.NodePortStrategyFluent<io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.NodePortNested<N>> {

            public N and();
            public N endNodePort();    }


    public interface PrivateNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.openshift.api.model.operator.v1.PrivateStrategyFluent<io.fabric8.openshift.api.model.operator.v1.EndpointPublishingStrategyFluent.PrivateNested<N>> {

            public N and();
            public N endPrivate();    }


}
